It is Daimler’s goal to offer its customers the best and most secure
products such as connected cars and other services. Daimler values the
work of security researchers and whitehat hackers who spend time and
effort helping us to achieve this goal.

For further information, please visit our
[Vulnerability Reporting Policy](https://www.daimler.com/whitehat/).
